**To delete termination settings**

The following ``delete-voice-connector-termination`` example deletes the termination settings for the specified Amazon Chime Voice Connector. ::

    aws chime delete-voice-connector-termination \
        --voice-connector-id abcdef1ghij2klmno3pqr4

This command produces no output.

For more information, see `Working with Amazon Chime Voice Connectors <https://docs.aws.amazon.com/chime/latest/ag/voice-connectors.html>`__ in the *Amazon Chime Administration Guide*.
